$def with (userId,shopId)
<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title>饿了么开放平台</title>
</head>
<body>
  <div class="w1000">
    <div class="userinfo">
      <p>当前登录用户ID为<span>$userId</span></p>
      <p>当前店铺id为<span>$shopId</span></p>
    </div>
    <div class="icon-box">
      <img src="https://fuss.alpha.elenet.me/0/71/ef76406ecd56a0cbac11a869eded1png.png" alt="">
      </br>
      智能配送助手
    </div>
    <dl>
      <dt class="abc">【智能配送助手】由【饿了么】进行开发</dt>
      <dd>
        饿了么商家开放平台作为一个服务集成平台，致力于满足商户的多样需求，提供合作伙伴更多的平台资源，服务商户接入，提供给商户更丰富的经营能力。同时，开放平台将通过提供一系列非业务性的，例如安全保障、服务监控告警、日志分析统计等解决方案，让开发者专注于业务系统的开发，降低接入者的开发成本。
      </dd>
    </dl>
  </div>

  <style>
    dt,dd{
      margin: 0;
    }
    .w1000{
      width: 1000px;
      margin: 0 auto;
    }
    .userinfo{
      text-align: center;
    }
    .icon-box{
      text-align: center;
    }
    .icon-box img{
      width: 200px;
      height: 200px;
    }
  </style>
</body>
</html>